{#style_dlg.title}

- {#style_dlg.text_tab}
- {#style_dlg.background_tab}
- {#style_dlg.block_tab}
- {#style_dlg.box_tab}
- {#style_dlg.border_tab}
- {#style_dlg.list_tab}
- {#style_dlg.positioning_tab}

{#style_dlg.text_font} |
{#style_dlg.text_size} |
| {#style_dlg.text_weight} |
{#style_dlg.text_style} |  | {#style_dlg.text_variant} |
{#style_dlg.text_lineheight} |
| {#style_dlg.text_case} |
{#style_dlg.text_color} |
{#style_dlg.text_decoration} |
| {#style_dlg.text_underline}
| {#style_dlg.text_overline}
| {#style_dlg.text_striketrough}
| {#style_dlg.text_blink}
| {#style_dlg.text_none}

{#style_dlg.background_color} |
{#style_dlg.background_image} |
{#style_dlg.background_repeat} |
{#style_dlg.background_attachment} |
{#style_dlg.background_hpos} |
{#style_dlg.background_vpos} |

{#style_dlg.block_wordspacing} |
{#style_dlg.block_letterspacing} |
{#style_dlg.block_vertical_alignment} |
{#style_dlg.block_text_align} |
{#style_dlg.block_text_indent} |
{#style_dlg.block_whitespace} |
{#style_dlg.block_display} |

{#style_dlg.box_width} |
| {#style_dlg.box_float} |
{#style_dlg.box_height} |
| {#style_dlg.box_clear} |

{#style_dlg.padding}

| {#style_dlg.same}
{#style_dlg.top} |
{#style_dlg.right} |
{#style_dlg.bottom} |
{#style_dlg.left} |

{#style_dlg.margin}

| {#style_dlg.same}
{#style_dlg.top} |
{#style_dlg.right} |
{#style_dlg.bottom} |
{#style_dlg.left} |

|  | {#style_dlg.style} |  | {#style_dlg.width} |  | {#style_dlg.color}
|  | {#style_dlg.same} |  | {#style_dlg.same} |  | {#style_dlg.same}
{#style_dlg.top} |  |  |  |
{#style_dlg.right} |  |  |  |
{#style_dlg.bottom} |  |  |  |
{#style_dlg.left} |  |  |  |

{#style_dlg.list_type} |
{#style_dlg.bullet_image} |
{#style_dlg.position} |

{#style_dlg.positioning_type} |  | {#style_dlg.visibility} |
{#style_dlg.width} |
| {#style_dlg.zindex} |
{#style_dlg.height} |
| {#style_dlg.overflow} |

{#style_dlg.placement}

| {#style_dlg.same}
{#style_dlg.top} |
{#style_dlg.right} |
{#style_dlg.bottom} |
{#style_dlg.left} |

{#style_dlg.clip}

| {#style_dlg.same}
{#style_dlg.top} |
{#style_dlg.right} |
{#style_dlg.bottom} |
{#style_dlg.left} |